Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1865)

Unified Diff: src/objects.h

Issue 2232653003: Reland of "[heap] Switch to 500k pages" (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: s/ShrinkPagesToHighWaterMark/ShrinkImmortalImmovablePages/ Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/objects.h
diff --git a/src/objects.h b/src/objects.h
index f5bece0a11fbe08d16a563fda13cc60f9891e786..2c260534959f26fd15e4d80b2286bdf34b25cbef 100644
--- a/src/objects.h
+++ b/src/objects.h
@@ -4712,6 +4712,7 @@ class FreeSpace: public HeapObject {
// Size is smi tagged when it is stored.
static const int kSizeOffset = HeapObject::kHeaderSize;
static const int kNextOffset = POINTER_SIZE_ALIGN(kSizeOffset + kPointerSize);
+ static const int kSize = kNextOffset + kPointerSize;
private:
DISALLOW_IMPLICIT_CONSTRUCTORS(FreeSpace);
@@ -10466,12 +10467,12 @@ class JSArray: public JSObject {
static const int kLengthOffset = JSObject::kHeaderSize;
static const int kSize = kLengthOffset + kPointerSize;
// 600 * KB is the Page::kMaxRegularHeapObjectSize defined in spaces.h which
Hannes Payer (out of office) 2016/08/10 21:17:35 Why not 300?
Michael Lippautz 2016/08/11 09:48:11 Crankshaft (and esp hydrogen stubs) don't check fo
// we do not want to include in objects.h
// Note that Page::kMaxRegularHeapObjectSize has to be in sync with
// kInitialMaxFastElementArray which is checked in a DCHECK in heap.cc.
static const int kInitialMaxFastElementArray =
- (600 * KB - FixedArray::kHeaderSize - kSize - AllocationMemento::kSize) /
+ (400 * KB - FixedArray::kHeaderSize - kSize - AllocationMemento::kSize) /
kPointerSize;
private:
@@ -10466,12 +10467,12 @@ class JSArray: public JSObject {
static const int kLengthOffset = JSObject::kHeaderSize;
static const int kSize = kLengthOffset + kPointerSize;
- // 600 * KB is the Page::kMaxRegularHeapObjectSize defined in spaces.h which
+ // 400 * KB is the Page::kMaxRegularHeapObjectSize defined in spaces.h which
Hannes Payer (out of office) 2016/08/10 21:17:35 Why not 300?
Michael Lippautz 2016/08/11 09:48:11 Crankshaft (and esp hydrogen stubs) don't check fo

Powered by Google App Engine
This is Rietveld 408576698